@@ -3,8 +3,7 @@ use warnings;
 use strict;
 use base qw(App::gh::Command);
 use App::gh::Utils;
-use JSON;
-
+use App::gh;
 
 =head1 NAME
 
